@@ -34,7 +34,8 @@ import datetime
 import getpass
 import functools
 import dataclasses
-from typing import Mapping, Optional, Sequence, Tuple, ClassVar, Dict, cast
+from typing import (Mapping, Optional, Sequence, Tuple, ClassVar, Dict, cast,
+                    TYPE_CHECKING)
 
 
 from PyQt5.QtCore import PYQT_VERSION_STR, QLibraryInfo, qVersion
@@ -58,13 +59,9 @@ import qutebrowser
 from qutebrowser.utils import log, utils, standarddir, usertypes, message, resources
 from qutebrowser.misc import objects, earlyinit, sql, httpclient, pastebin, elf
 from qutebrowser.browser import pdfjs
-from qutebrowser.config import config, websettings
-
-try:
-    from qutebrowser.browser.webengine import webenginesettings
-except ImportError:  # pragma: no cover
-    webenginesettings = None  # type: ignore[assignment]
-
+from qutebrowser.config import config
+if TYPE_CHECKING:
+    from qutebrowser.config import websettings
 
 _LOGO = r'''
          ______     ,,
@@ -92,7 +89,6 @@ class DistributionInfo:
 
     id: Optional[str]
     parsed: 'Distribution'
-    version: Optional[utils.VersionNumber]
     pretty: str
 
 
@@ -147,7 +143,6 @@ def distribution() -> Optional[DistributionInfo]:
     Returns:
         A DistributionInfo object, or None if no info could be determined.
             parsed: A Distribution enum member
-            version: A Version object, or None
             pretty: Always a string (might be "Unknown")
     """
     info = _parse_os_release()
@@ -159,12 +154,6 @@ def distribution() -> Optional[DistributionInfo]:
         pretty = info.get('NAME', 'Unknown')
     assert pretty is not None
 
-    dist_version: Optional[utils.VersionNumber] = None
-    for version_key in ['VERSION', 'VERSION_ID']:
-        if version_key in info:
-            dist_version = utils.VersionNumber.parse(info[version_key])
-            break
-
     dist_id = info.get('ID', None)
     id_mappings = {
         'funtoo': 'gentoo',  # does not have ID_LIKE=gentoo
@@ -187,8 +176,7 @@ def distribution() -> Optional[DistributionInfo]:
         else:
             break
 
-    return DistributionInfo(
-        parsed=parsed, version=dist_version, pretty=pretty, id=dist_id)
+    return DistributionInfo(parsed=parsed, pretty=pretty, id=dist_id)
 
 
 def is_flatpak() -> bool:
@@ -609,7 +597,7 @@ class WebEngineVersions:
         return s
 
     @classmethod
-    def from_ua(cls, ua: websettings.UserAgent) -> 'WebEngineVersions':
+    def from_ua(cls, ua: 'websettings.UserAgent') -> 'WebEngineVersions':
         """Get the versions parsed from a user agent.
 
         This is the most reliable and "default" way to get this information (at least
@@ -712,7 +700,7 @@ class WebEngineVersions:
             # do this kind of "downgrade" when we know we're using PyInstaller.
             frozen = hasattr(sys, 'frozen')
             log.misc.debug(f"PyQt5 >= 5.15.3, frozen {frozen}")
-            if frozen:  # pragma: no cover
+            if frozen:
                 parsed = utils.VersionNumber(5, 15, 2)
 
         return cls(
@@ -754,7 +742,7 @@ def qtwebengine_versions(avoid_init: bool = False) -> WebEngineVersions:
     - https://www.chromium.org/developers/calendar
     - https://chromereleases.googleblog.com/
     """
-    assert webenginesettings is not None
+    from qutebrowser.browser.webengine import webenginesettings
 
     if webenginesettings.parsed_user_agent is None and not avoid_init:
         webenginesettings.init_user_agent()
@@ -950,9 +938,6 @@ def opengl_info() -> Optional[OpenGLInfo]:  # pragma: no cover
     """
     assert QApplication.instance()
 
-    # Some setups can segfault in here if we don't do this.
-    utils.libgl_workaround()
-
     override = os.environ.get('QUTE_FAKE_OPENGL')
     if override is not None:
         log.init.debug("Using override {}".format(override))
